## 各渠道公募基金销售保有规模占比

接口：fund_sales_ratio

描述：获取各渠道公募基金销售保有规模占比数据，年度更新

限量：单次最大100行数据，数据从2015年开始公布，当前数据量很小

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| 年份 | str | N | 年度 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| year | int | Y | 年度 |
| bank | float | Y | 商业银行（%） |
| sec_comp | float | Y | 证券公司（%） |
| fund_comp | float | Y | 基金公司直销（%） |
| indep_comp | float | Y | 独立基金销售机构（%） |
| rests | float | Y | 其他（%） |

接口示例

```python
pro = ts.pro_api()

df = pro.fund_sales_ratio()
```

数据示例

```python
year   bank sec_comp fund_comp indep_comp rests
0  2015  25.22    10.01     61.90       2.14  0.73
```